@@ -124,9 +124,9 @@ void LatitudeGUI::show_lat() {
     layout_location->addRow(tr("acc :"), location_acc);
 
     // source button
-    QPushButton *source_loc = new QPushButton(tr("Auto &loc"));
-    QPushButton *source_cell = new QPushButton(tr("Auto &cell"));
-    QPushButton *source_gps = new QPushButton(tr("Auto &gps"));
+    QPushButton *source_loc = new QPushButton(tr("Update with &IP"));
+    QPushButton *source_cell = new QPushButton(tr("Update with &Cell"));
+    QPushButton *source_gps = new QPushButton(tr("Update with &Gps"));
     // source layout
     QHBoxLayout *layout_source = new QHBoxLayout();
     layout_source->addWidget(source_loc);
